@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.027001';
+$POEx::IRC::Backend::VERSION = '0.027002';
 use strictures 1;
 use Carp;
 
@@ -58,9 +58,7 @@ has filter_irc => (
   lazy    => 1,
   isa     => InstanceOf['POE::Filter'],
   is      => 'ro',
-  default => sub {
-    POE::Filter::IRCv3->new(colonify => 1)
-  },
+  default => sub { POE::Filter::IRCv3->new },
 );
 
 has filter_line => (
@@ -634,6 +632,7 @@ sub send {
       ( $out->has_prefix ? (prefix  => $out->prefix) : () ),
       ( $out->has_params ? (params  => $out->params) : () ),
       ( $out->has_tags   ? (tags    => $out->tags  ) : () ),
+      ( $out->has_colonify ? (colonify => $out->colonify) : () ),
     };
   }
 
@@ -862,12 +861,13 @@ stacked with L</filter_line> (at the time the attribute is built).
 
 =head3 filter_irc
 
-A L<POE::Filter::IRCv3> instance with B<colonify> enabled, by default.
+A L<POE::Filter::IRCv3> instance with B<colonify> disabled, by default (this
+behavior changed in v0.28.x).
 
-A client-side Backend will probably want a non-colonifying filter:
+A server-side Backend may want a colonifying filter:
 
   my $backend = POEx::IRC::Backend->new(
-    filter_irc => POE::Filter::IRCv3->new(colonify => 0),
+    filter_irc => POE::Filter::IRCv3->new(colonify => 1),
     ...
   );
 
